==> rdc_flutter_sdk-0.0.20-dev-1.tar.gz: example/lib/screens/setting/setting_screen.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:shop_app/constants.dart';
import 'package:shop_app/controllers/example_controller.dart';
import 'package:shop_app/screens/setting_config/setting_config.dart';
import 'package:shop_app/size_config.dart';
import 'package:floating_action_bubble/floating_action_bubble.dart';
import './components/body.dart';
import 'package:package_info_plus/package_info_plus.dart';

class SettingScreen extends StatefulWidget {
  static String routeName = "/setting";

  @override
  State<SettingScreen> createState() => _SettingScreenState();
}

class _SettingScreenState extends State<SettingScreen>
    with SingleTickerProviderStateMixin {
  late Animation<double> _animation;
  late AnimationController _animationController;

  final RabbitDataInstance rabbitData = Get.find(tag: 'rabbit_data');
  final ExampleController eventController = Get.find();

  final _eventNameController = TextEditingController();
  final _eventValueController = TextEditingController();

  final _key1Controller = TextEditingController();
  final _value1Controller = TextEditingController();
  final _key2Controller = TextEditingController();
  final _value2Controller = TextEditingController();

  var appVer = '';
  var appVerNum = '';

  @override
  void initState() {
    _animationController = AnimationController(
      vsync: this,
      duration: Duration(milliseconds: 260),
    );

    final curvedAnimation =
        CurvedAnimation(curve: Curves.easeInOut, parent: _animationController);
    _animation = Tween<double>(begin: 0, end: 1).animate(curvedAnimation);

    _initEvent();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    // You have to call it on your starting screen
    SizeConfig().init(context);
    eventController.getEvents();
    return Scaffold(
        appBar: AppBar(
          title: Text('Event Log : $appVer ($appVerNum)'),
          centerTitle: true,
          titleTextStyle: TextStyle(
              fontWeight: FontWeight.bold, fontSize: 16, color: Colors.black),
          actions: [
            IconButton(
                onPressed: () {
                  Navigator.pushNamed(context, SettingConfigScreen.routeName);
                },
                icon: Icon(Icons.settings))
          ],
        ),
        body: Body(),
        // floatingActionButtonLocation: FloatingActionButtonLocation.endDocked,

        //Init Floating Action Bubble
        floatingActionButton: Padding(
          padding: const EdgeInsets.only(bottom: 20),
          child: FloatingActionBubble(
            // Menu items
            items: <Bubble>[
              Bubble(
                title: "End Session",
                iconColor: Colors.white,
                bubbleColor: Colors.orange.shade300,
                icon: Icons.stop,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  await eventController.sessionEnd();
                  _animationController.reverse();
                },
              ),
              Bubble(
                title: "Start Session",
                iconColor: Colors.white,
                bubbleColor: kPrimaryColor,
                icon: Icons.play_arrow,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  await eventController.sessionStart();
                  _animationController.reverse();
                },
              ),
              Bubble(
                title: "Clear All",
                iconColor: Colors.white,
                bubbleColor: Colors.red,
                icon: Icons.delete,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  await eventController.clearAll();
                  _animationController.reverse();
                },
              ),
              Bubble(
                title: "Clear Cache",
                iconColor: Colors.white,
                bubbleColor: Colors.red.shade300,
                icon: Icons.clear,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  await eventController.clearCache();
                  _animationController.reverse();
                },
              ),
              // Floating action menu item
              Bubble(
                title: "Upload Event",
                iconColor: Colors.white,
                bubbleColor: Colors.lightBlue,
                icon: Icons.publish,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  if (rabbitData.config.offlineMode)
                    Get.snackbar('Offline Mode!', 'Let\'s check config',
                        colorText: Colors.white,
                        backgroundColor: Colors.red.shade300,
                        snackPosition: SnackPosition.TOP,
                        margin:
                            EdgeInsets.symmetric(vertical: 10, horizontal: 10));

                  await eventController.uploadEvent();
                  _animationController.reverse();
                },
              ),
              //Floating action menu item
              Bubble(
                title: "Add Event",
                iconColor: Colors.white,
                bubbleColor: Colors.lightGreen,
                icon: Icons.add,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  Get.defaultDialog(
                      title: "Add Event",
                      content: Column(
                        children: [
                          TextField(
                            controller: _eventNameController,
                            decoration: InputDecoration(
                              labelText: 'Event Name',
                              suffixIcon: IconButton(
                                onPressed: _eventNameController.clear,
                                icon: Icon(Icons.clear),
                              ),
                            ),
                          ),
                          SizedBox(height: 20),
                          TextField(
                            controller: _eventValueController,
                            decoration: InputDecoration(
                              labelText: 'Event Value',
                              suffixIcon: IconButton(
                                onPressed: _eventValueController.clear,
                                icon: Icon(Icons.clear),
                              ),
                            ),
                          ),
                          SizedBox(height: 5),
                          Divider(),
                          SizedBox(height: 5),
                          Row(
                            children: [
                              Expanded(
                                child: TextField(
                                  controller: _key1Controller,
                                  decoration: InputDecoration(
                                    labelText: 'Key 1',
                                    suffixIcon: IconButton(
                                      onPressed: _key1Controller.clear,
                                      icon: Icon(Icons.clear),
                                    ),
                                  ),
                                ),
                              ),
                              SizedBox(width: 20),
                              Expanded(
                                child: TextField(
                                  controller: _value1Controller,
                                  decoration: InputDecoration(
                                    labelText: 'Value 1',
                                    suffixIcon: IconButton(
                                      onPressed: _value1Controller.clear,
                                      icon: Icon(Icons.clear),
                                    ),
                                  ),
                                ),
                              )
                            ],
                          ),
                          SizedBox(height: 20),
                          Row(
                            children: [
                              Expanded(
                                child: TextField(
                                  controller: _key2Controller,
                                  decoration: InputDecoration(
                                    labelText: 'Key 2',
                                    suffixIcon: IconButton(
                                      onPressed: _key2Controller.clear,
                                      icon: Icon(Icons.clear),
                                    ),
                                  ),
                                ),
                              ),
                              SizedBox(width: 20),
                              Expanded(
                                child: TextField(
                                  controller: _value2Controller,
                                  decoration: InputDecoration(
                                    labelText: 'Value 2',
                                    suffixIcon: IconButton(
                                      onPressed: _value2Controller.clear,
                                      icon: Icon(Icons.clear),
                                    ),
                                  ),
                                ),
                              )
                            ],
                          )
                        ],
                      ),
                      textCancel: 'Close',
                      textConfirm: 'Add',
                      confirmTextColor: Colors.white,
                      onCancel: () {
                        Get.back();
                        _animationController.reverse();
                      },
                      onConfirm: () async {
                        Get.back();
                        await _saveEvent();
                        _animationController.reverse();
                      },
                      radius: 30);
                },
              ),
            ],

            // animation controller
            animation: _animation,

            // On pressed change animation state
            onPress: () => _animationController.isCompleted
                ? _animationController.reverse()
                : _animationController.forward(),

            // Floating Action button Icon color
            iconColor: kPrimaryColor,

            // Flaoting Action button Icon
            iconData: Icons.menu,
            backGroundColor: Colors.white,
          ),
        ));
  }

  _initEvent() async {
    SharedPreferences sharedPreference = await SharedPreferences.getInstance();

    _eventNameController.text =
        sharedPreference.getString('eventName') ?? 'click';
    _eventValueController.text =
        sharedPreference.getString('eventValue') ?? 'compelete';

    _key1Controller.text = sharedPreference.getString('key1') ?? '';
    _value1Controller.text = sharedPreference.getString('value1') ?? '';
    _key2Controller.text = sharedPreference.getString('key2') ?? '';
    _value2Controller.text = sharedPreference.getString('value2') ?? '';

    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    setState(() {
      appVer = packageInfo.version;
      appVerNum = packageInfo.buildNumber;
    });
  }

  _saveEvent() async {
    SharedPreferences sharedPreference = await SharedPreferences.getInstance();

    sharedPreference.setString('eventName', _eventNameController.text);
    sharedPreference.setString('eventValue', _eventValueController.text);

    sharedPreference.setString('key1', _key1Controller.text);
    sharedPreference.setString('value1', _value1Controller.text);
    sharedPreference.setString('key2', _key2Controller.text);
    sharedPreference.setString('value2', _value2Controller.text);

    Map<String, String>? dataLayer = null;

    if (_key1Controller.text.isNotEmpty) {
      if (dataLayer == null) dataLayer = <String, String>{};
      dataLayer.addAll({_key1Controller.text: _value1Controller.text});
    }

    if (_key2Controller.text.isNotEmpty) {
      if (dataLayer == null) dataLayer = <String, String>{};
      dataLayer.addAll({_key2Controller.text: _value2Controller.text});
    }

    await eventController.addEvent(
        eventName: _eventNameController.text,
        eventValue: _eventValueController.text,
        dataLayer: dataLayer);

    _animationController.reverse();
  }
}

==> rdc_flutter_sdk_2-0.0.1-dev.1.tar.gz: example/lib/screens/setting/setting_screen.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:rdc_flutter_sdk_2/rabbit_data.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:shop_app/constants.dart';
import 'package:shop_app/controllers/example_controller.dart';
import 'package:shop_app/screens/setting_config/setting_config.dart';
import 'package:shop_app/size_config.dart';
import 'package:floating_action_bubble/floating_action_bubble.dart';
import './components/body.dart';
import 'package:package_info_plus/package_info_plus.dart';

class SettingScreen extends StatefulWidget {
  static String routeName = "/setting";

  @override
  State<SettingScreen> createState() => _SettingScreenState();
}

class _SettingScreenState extends State<SettingScreen>
    with SingleTickerProviderStateMixin {
  late Animation<double> _animation;
  late AnimationController _animationController;

  final RabbitDataInstance rabbitData = Get.find(tag: 'rabbit_data');
  final ExampleController eventController = Get.find();

  final _eventNameController = TextEditingController();
  final _eventValueController = TextEditingController();

  final _key1Controller = TextEditingController();
  final _value1Controller = TextEditingController();
  final _key2Controller = TextEditingController();
  final _value2Controller = TextEditingController();

  var appVer = '';
  var appVerNum = '';

  @override
  void initState() {
    _animationController = AnimationController(
      vsync: this,
      duration: Duration(milliseconds: 260),
    );

    final curvedAnimation =
        CurvedAnimation(curve: Curves.easeInOut, parent: _animationController);
    _animation = Tween<double>(begin: 0, end: 1).animate(curvedAnimation);

    _initEvent();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    // You have to call it on your starting screen
    SizeConfig().init(context);
    eventController.getEvents();
    return Scaffold(
        appBar: AppBar(
          title: Text('Event Log : $appVer ($appVerNum)'),
          centerTitle: true,
          titleTextStyle: TextStyle(
              fontWeight: FontWeight.bold, fontSize: 16, color: Colors.black),
          actions: [
            IconButton(
                onPressed: () {
                  Navigator.pushNamed(context, SettingConfigScreen.routeName);
                },
                icon: Icon(Icons.settings))
          ],
        ),
        body: Body(),
        floatingActionButtonLocation: FloatingActionButtonLocation.endDocked,

        //Init Floating Action Bubble
        floatingActionButton: Padding(
          padding: const EdgeInsets.only(bottom: 20),
          child: FloatingActionBubble(
            // Menu items
            items: <Bubble>[
              Bubble(
                title: "End Session",
                iconColor: Colors.white,
                bubbleColor: Colors.orange.shade300,
                icon: Icons.stop,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  await eventController.sessionEnd();
                  _animationController.reverse();
                },
              ),
              Bubble(
                title: "Start Session",
                iconColor: Colors.white,
                bubbleColor: kPrimaryColor,
                icon: Icons.play_arrow,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  await eventController.sessionStart();
                  _animationController.reverse();
                },
              ),
              Bubble(
                title: "Clear All",
                iconColor: Colors.white,
                bubbleColor: Colors.red,
                icon: Icons.delete,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  await eventController.clearAll();
                  _animationController.reverse();
                },
              ),
              Bubble(
                title: "Clear Cache",
                iconColor: Colors.white,
                bubbleColor: Colors.red.shade300,
                icon: Icons.clear,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  await eventController.clearCache();
                  _animationController.reverse();
                },
              ),
              // Floating action menu item
              Bubble(
                title: "Upload Event",
                iconColor: Colors.white,
                bubbleColor: Colors.lightBlue,
                icon: Icons.publish,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  if (rabbitData.config.offlineMode)
                    Get.snackbar('Offline Mode!', 'Let\'s check config',
                        colorText: Colors.white,
                        backgroundColor: Colors.red.shade300,
                        snackPosition: SnackPosition.TOP,
                        margin:
                            EdgeInsets.symmetric(vertical: 10, horizontal: 10));

                  await eventController.uploadEvent();
                  _animationController.reverse();
                },
              ),
              //Floating action menu item
              Bubble(
                title: "Add Event",
                iconColor: Colors.white,
                bubbleColor: Colors.lightGreen,
                icon: Icons.add,
                titleStyle: TextStyle(fontSize: 16, color: Colors.white),
                onPress: () async {
                  Get.defaultDialog(
                      title: "Add Event",
                      content: Column(
                        children: [
                          TextField(
                            controller: _eventNameController,
                            decoration: InputDecoration(
                              labelText: 'Event Name',
                              suffixIcon: IconButton(
                                onPressed: _eventNameController.clear,
                                icon: Icon(Icons.clear),
                              ),
                            ),
                          ),
                          SizedBox(height: 20),
                          TextField(
                            controller: _eventValueController,
                            decoration: InputDecoration(
                              labelText: 'Event Value',
                              suffixIcon: IconButton(
                                onPressed: _eventValueController.clear,
                                icon: Icon(Icons.clear),
                              ),
                            ),
                          ),
                          SizedBox(height: 5),
                          Divider(),
                          SizedBox(height: 5),
                          Row(
                            children: [
                              Expanded(
                                child: TextField(
                                  controller: _key1Controller,
                                  decoration: InputDecoration(
                                    labelText: 'Key 1',
                                    suffixIcon: IconButton(
                                      onPressed: _key1Controller.clear,
                                      icon: Icon(Icons.clear),
                                    ),
                                  ),
                                ),
                              ),
                              SizedBox(width: 20),
                              Expanded(
                                child: TextField(
                                  controller: _value1Controller,
                                  decoration: InputDecoration(
                                    labelText: 'Value 1',
                                    suffixIcon: IconButton(
                                      onPressed: _value1Controller.clear,
                                      icon: Icon(Icons.clear),
                                    ),
                                  ),
                                ),
                              )
                            ],
                          ),
                          SizedBox(height: 20),
                          Row(
                            children: [
                              Expanded(
                                child: TextField(
                                  controller: _key2Controller,
                                  decoration: InputDecoration(
                                    labelText: 'Key 2',
                                    suffixIcon: IconButton(
                                      onPressed: _key2Controller.clear,
                                      icon: Icon(Icons.clear),
                                    ),
                                  ),
                                ),
                              ),
                              SizedBox(width: 20),
                              Expanded(
                                child: TextField(
                                  controller: _value2Controller,
                                  decoration: InputDecoration(
                                    labelText: 'Value 2',
                                    suffixIcon: IconButton(
                                      onPressed: _value2Controller.clear,
                                      icon: Icon(Icons.clear),
                                    ),
                                  ),
                                ),
                              )
                            ],
                          )
                        ],
                      ),
                      textCancel: 'Close',
                      textConfirm: 'Add',
                      confirmTextColor: Colors.white,
                      onCancel: () {
                        Get.back();
                        _animationController.reverse();
                      },
                      onConfirm: () async {
                        Get.back();
                        await _saveEvent();
                        _animationController.reverse();
                      },
                      radius: 30);
                },
              ),
            ],

            // animation controller
            animation: _animation,

            // On pressed change animation state
            onPress: () => _animationController.isCompleted
                ? _animationController.reverse()
                : _animationController.forward(),

            // Floating Action button Icon color
            iconColor: kPrimaryColor,

            // Flaoting Action button Icon
            iconData: Icons.menu,
            backGroundColor: Colors.white,
          ),
        ));
  }

  _initEvent() async {
    SharedPreferences sharedPreference = await SharedPreferences.getInstance();

    _eventNameController.text =
        sharedPreference.getString('eventName') ?? 'click';
    _eventValueController.text =
        sharedPreference.getString('eventValue') ?? 'compelete';

    _key1Controller.text = sharedPreference.getString('key1') ?? '';
    _value1Controller.text = sharedPreference.getString('value1') ?? '';
    _key2Controller.text = sharedPreference.getString('key2') ?? '';
    _value2Controller.text = sharedPreference.getString('value2') ?? '';

    PackageInfo packageInfo = await PackageInfo.fromPlatform();
    setState(() {
      appVer = packageInfo.version;
      appVerNum = packageInfo.buildNumber;
    });
  }

  _saveEvent() async {
    SharedPreferences sharedPreference = await SharedPreferences.getInstance();

    sharedPreference.setString('eventName', _eventNameController.text);
    sharedPreference.setString('eventValue', _eventValueController.text);

    sharedPreference.setString('key1', _key1Controller.text);
    sharedPreference.setString('value1', _value1Controller.text);
    sharedPreference.setString('key2', _key2Controller.text);
    sharedPreference.setString('value2', _value2Controller.text);

    Map<String, String>? dataLayer = null;

    if (_key1Controller.text.isNotEmpty) {
      if (dataLayer == null) dataLayer = <String, String>{};
      dataLayer.addAll({_key1Controller.text: _value1Controller.text});
    }

    if (_key2Controller.text.isNotEmpty) {
      if (dataLayer == null) dataLayer = <String, String>{};
      dataLayer.addAll({_key2Controller.text: _value2Controller.text});
    }

    await eventController.addEvent(
        eventName: _eventNameController.text,
        eventValue: _eventValueController.text,
        dataLayer: dataLayer);

    _animationController.reverse();
  }
}
